pyxmpp.exceptions

Package pyxmpp :: Module exceptions |
[hide private]

# Module exceptions

source code

PyXMPP exceptions.

This module defines all exceptions raised by PyXMPP.

Classes | [hide private]
| Error Base class for all PyXMPP exceptions.
| JIDError Exception raised when invalid JID is used
| StreamError Base class for all stream errors.
| StreamEncryptionRequired Exception raised when stream encryption is requested, but not used.
| HostMismatch Exception raised when the connected host name is other then requested.
| FatalStreamError Base class for all fatal Stream exceptions.
| StreamParseError Raised when invalid XML is received in an XMPP stream.
| StreamAuthenticationError Raised when stream authentication fails.
| TLSNegotiationFailed Raised when stream TLS negotiation fails.
| TLSError Raised on TLS error during stream processing.
| TLSNegotiatedButNotAvailableError Raised on TLS error during stream processing.
| SASLNotAvailable Raised when SASL authentication is requested, but not available.
| SASLMechanismNotAvailable Raised when none of SASL authentication mechanisms requested is available.
| SASLAuthenticationFailed Raised when stream SASL authentication fails.
| StringprepError Exception raised when string preparation results in error.
| ClientError Raised on a client error.
| FatalClientError Raised on a fatal client error.
| ClientStreamError Raised on a client stream error.
| FatalClientStreamError Raised on a fatal client stream error.
| LegacyAuthenticationError Raised on a legacy authentication error.
| RegistrationError Raised on a in-band registration error.
| ComponentStreamError Raised on a component error.
| FatalComponentStreamError Raised on a fatal component error.
| ProtocolError Raised when there is something wrong with a stanza processed.
| BadRequestProtocolError Raised when invalid stanza is processed and 'bad-request' error should be reported.
| JIDMalformedProtocolError Raised when invalid JID is encountered.
| FeatureNotImplementedProtocolError Raised when stanza requests a feature which is not (yet) implemented.

Variables | [hide private]
| __revision__ = ``'``$Id: error.py 647 2006-08-26 18:27:39Z jajcus $``'``
| __package__ = ``'``pyxmpp``'``

Imports: logging